@@ -1,6 +1,6 @@
 //! Shadowsocks Local Server Context
 
-use std::sync::Arc;
+use std::{net::SocketAddr, sync::Arc};
 
 use shadowsocks::{
     config::ServerType,
@@ -100,6 +100,14 @@ impl ServiceContext {
         }
     }
 
+    /// Check if client should be blocked
+    pub fn check_client_blocked(&self, addr: &SocketAddr) -> bool {
+        match self.acl {
+            None => false,
+            Some(ref acl) => acl.check_client_blocked(addr),
+        }
+    }
+
     /// Try to connect IPv6 addresses first if hostname could be resolved to both IPv4 and IPv6
     pub fn set_ipv6_first(&mut self, ipv6_first: bool) {
         let context = Arc::get_mut(&mut self.context).expect("cannot set ipv6_first on a shared context");
